@@ -1,7 +1,5 @@
 expect_comparable <- function(object, expected, ...) {
-  object   <- unclass(object)
-  expected <- unclass(expected)
-  expect_equivalent(object, expected, ...)
+  testthat::expect_equal(object, expected, ..., ignore_attr = TRUE)
 }
 
 test_that("scalar fracture()", {
@@ -21,6 +19,21 @@ test_that("small fracture()", {
   expect_comparable(as.fracture(1 / 1e5), "1/100000")
 })
 
+test_that("extreme fracture()", {
+  expect_comparable(fracture(0), "0/1")
+  expect_comparable(fracture(.Machine$double.eps), "0/10000000")
+  expect_comparable(fracture(1), "1/1")
+  expect_comparable(fracture(1 - .Machine$double.eps), "10000000/10000000")
+
+  expect_comparable(
+    fracture(
+      c(0, .Machine$double.eps, 1/5, 1 - .Machine$double.eps, 1),
+      common_denom = TRUE
+    ),
+    c("0/5", "0/5", "1/5", "5/5", "5/5")
+  )
+})
+
 test_that("irrational fracture()", {
   expect_comparable(fracture(pi, max_denom = 100), "22/7")
 })
@@ -71,6 +84,19 @@ test_that("really long vector fracture()", {
   expect_comparable(fracture(test_decimal), test_fraction)
 })
 
+test_that("explicit denom fracture()", {
+  expect_comparable(fracture(2 / 11, denom = 10), "2/10")
+  expect_comparable(
+    fracture(rep(2 / 11, 2), denom = c(10, 12)), c("2/10", "2/12")
+  )
+  expect_comparable(
+    fracture(24 / 11, denom = 10, mixed = TRUE), "2 2/10"
+  )
+  expect_comparable(
+    fracture(c(6, 20) / 11, denom = 10, mixed = TRUE), c("5/10", "1 8/10")
+  )
+})
+
 test_that("improper fracture()", {
   expect_comparable(fracture(c(1.5, 2)), c("3/2", "2/1"))
   expect_comparable(as.fracture(c(1.5, 2)), c("3/2", "2/1"))
@@ -309,4 +335,8 @@ test_that("fracture() errors", {
   expect_error(fracture(Inf))
   expect_error(fracture(-Inf))
   expect_error(fracture(c(0.5, NA, 1.5)))
+  expect_error(fracture(1, denom = NA))
+  expect_error(fracture(1, denom = Inf))
+  expect_error(fracture(1, denom = 1:2))
+  expect_error(fracture(1:10, denom = 1:2))
 })
